Welcome to the LexNLP documentation!
==================================

.. image:: https://s3.amazonaws.com/lexpredict.com-marketing/graphics/lexpredict_lexnlp_logo_horizontal_1.png
   :width: 200px
   :alt: LexNLP
   :align: center


|


Table of Contents
------------
.. toctree::
    :maxdepth: 4

    about
    lexnlp
    changes
    license


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
